[![PyPI](https://badgen.net/pypi/v/Thermobar)](https://pypi.org/project/Thermobar/)
[![Build Status](https://github.com/PennyWieser/Thermobar/actions/workflows/main.yml/badge.svg?branch=main)](https://github.com/PennyWieser/Thermobar/actions/workflows/main.yml)
[![codecov](https://codecov.io/gh/PennyWieser/Thermobar/branch/main/graph/badge.svg)](https://codecov.io/gh/PennyWieser/Thermobar/branch/main)

Thermobar is a python tool for thermobarometry, chemometry and mineral equilibrium.
Thermobar allows users to easily choose between more than 100 popular parameterizations involving liquid, olivine-liquid, olivine-spinel, 
pyroxene only, pyroxene-liquid, two pyroxene, feldspar-liquid, two feldspar, amphibole and amphibole-liquid, garnet and biotite equilibrium. 

It can be downloaded via pip, on Github (you are here!), and extensive documentation and 
example videos and Jupyter Notebooks are available at https://thermobar.readthedocs.io/en/latest/index.html

If you want to use Machine learning models, you will need to pip install a separate package (the pkl and onnx files are too big for one release). Please see the instructions here:
https://thermobar.readthedocs.io/en/latest/Examples/Cpx_Cpx_Liq_Thermobarometry/MachineLearning_Cpx_Liq_Thermobarometry.html


Find more information in Volcanica - and please make sure you cite this work!!!
https://www.jvolcanica.org/ojs/index.php/volcanica/article/view/161
________________________________
Want your model in Thermobar?
________________________________
Getting your model into Thermobar will hopefully help to increase usage. 
I am happy to help you with this. You will need to supply me with your scripts or excel spreadsheet showing how the model works, 
your calibration dataset, and some example calculations for benchmarking. 

For Machine Learning models, please see the read the docs page. 
